part of trober_sdk.api;

class DefaultApi {
  final DefaultApiDelegate apiDelegate;
  DefaultApi(ApiClient apiClient)
      : assert(apiClient != null),
        apiDelegate = DefaultApiDelegate(apiClient);

  /// List all Carriers
  ///
  /// List all Carriers
  Future<List<Carrier>> carriersGet({Options options}) async {
    final response = await apiDelegate.carriersGet(
      options: options,
    );

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.carriersGet_decode(response);
    }
  }

  /// List all Carriers
  ///
  /// List all Carriers
  /// Get carrier details
  ///
  /// Get carrier details
  Future<Carrier> carriersIdGet(String id, {Options options}) async {
    final response = await apiDelegate.carriersIdGet(
      id,
      options: options,
    );

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.carriersIdGet_decode(response);
    }
  }

  /// Get carrier details
  ///
  /// Get carrier details
  /// Update an existing carrier
  ///
  /// Update an existing carrier
  Future<Carrier> carriersIdPatch(String id,
      {Options options, Carrier carrier}) async {
    final response = await apiDelegate.carriersIdPatch(id,
        options: options, carrier: carrier);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.carriersIdPatch_decode(response);
    }
  }

  /// Update an existing carrier
  ///
  /// Update an existing carrier
  /// Create a new Carrier
  ///
  /// Create a new Carrier
  Future<Carrier> carriersPost({Options options, Carrier carrier}) async {
    final response =
        await apiDelegate.carriersPost(options: options, carrier: carrier);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.carriersPost_decode(response);
    }
  }

  /// Create a new Carrier
  ///
  /// Create a new Carrier
  /// List all Containers
  ///
  /// List all Containers
  Future<List<Container>> containersGet({Options options}) async {
    final response = await apiDelegate.containersGet(
      options: options,
    );

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.containersGet_decode(response);
    }
  }

  /// List all Containers
  ///
  /// List all Containers
  /// Get container details
  ///
  /// Get container details
  Future<Container> containersIdGet(String id, {Options options}) async {
    final response = await apiDelegate.containersIdGet(
      id,
      options: options,
    );

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.containersIdGet_decode(response);
    }
  }

  /// Get container details
  ///
  /// Get container details
  /// Update an existing container
  ///
  /// Update an existing container
  Future<Container> containersIdPatch(String id,
      {Options options, Container container}) async {
    final response = await apiDelegate.containersIdPatch(id,
        options: options, container: container);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.containersIdPatch_decode(response);
    }
  }

  /// Update an existing container
  ///
  /// Update an existing container
  /// Create a new Container
  ///
  /// Create a new Container
  Future<Container> containersPost(
      {Options options, Container container}) async {
    final response = await apiDelegate.containersPost(
        options: options, container: container);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.containersPost_decode(response);
    }
  }

  /// Create a new Container
  ///
  /// Create a new Container
  /// List all Customers
  ///
  /// List all Customers
  Future<List<Customer>> customersGet({Options options}) async {
    final response = await apiDelegate.customersGet(
      options: options,
    );

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.customersGet_decode(response);
    }
  }

  /// List all Customers
  ///
  /// List all Customers
  /// Get customer details
  ///
  /// Get customer details
  Future<Customer> customersIdGet(String id, {Options options}) async {
    final response = await apiDelegate.customersIdGet(
      id,
      options: options,
    );

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.customersIdGet_decode(response);
    }
  }

  /// Get customer details
  ///
  /// Get customer details
  /// Update an existing customer
  ///
  /// Update an existing customer
  Future<Customer> customersIdPatch(String id,
      {Options options, Customer customer}) async {
    final response = await apiDelegate.customersIdPatch(id,
        options: options, customer: customer);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.customersIdPatch_decode(response);
    }
  }

  /// Update an existing customer
  ///
  /// Update an existing customer
  /// Create a new Customer
  ///
  /// Create a new Customer
  Future<Customer> customersPost({Options options, Customer customer}) async {
    final response =
        await apiDelegate.customersPost(options: options, customer: customer);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.customersPost_decode(response);
    }
  }

  /// Create a new Customer
  ///
  /// Create a new Customer
  /// Get server health
  ///
  /// Get server health status
  Future healthGet({Options options}) async {
    final response = await apiDelegate.healthGet(
      options: options,
    );

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.healthGet_decode(response);
    }
  }

  /// Get server health
  ///
  /// Get server health status
  /// List all Orders
  ///
  /// List all Orders
  Future<List<Order>> ordersGet({Options options}) async {
    final response = await apiDelegate.ordersGet(
      options: options,
    );

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.ordersGet_decode(response);
    }
  }

  /// List all Orders
  ///
  /// List all Orders
  /// Get order details
  ///
  /// Get order details
  Future<Order> ordersIdGet(String id, {Options options}) async {
    final response = await apiDelegate.ordersIdGet(
      id,
      options: options,
    );

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.ordersIdGet_decode(response);
    }
  }

  /// Get order details
  ///
  /// Get order details
  /// Update an existing order
  ///
  /// Update an existing order
  Future<Order> ordersIdPatch(String id, {Options options, Order order}) async {
    final response =
        await apiDelegate.ordersIdPatch(id, options: options, order: order);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.ordersIdPatch_decode(response);
    }
  }

  /// Update an existing order
  ///
  /// Update an existing order
  /// Create a new Order
  ///
  /// Create a new Order
  Future<Order> ordersPost({Options options, Order order}) async {
    final response =
        await apiDelegate.ordersPost(options: options, order: order);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.ordersPost_decode(response);
    }
  }

  /// Create a new Order
  ///
  /// Create a new Order
  /// List all tenants
  ///
  /// List all tenants
  Future<List<Tenant>> tenantsGet({Options options}) async {
    final response = await apiDelegate.tenantsGet(
      options: options,
    );

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.tenantsGet_decode(response);
    }
  }

  /// List all tenants
  ///
  /// List all tenants
  /// Get tenant details
  ///
  /// Get tenant details
  Future<Tenant> tenantsIdGet(String id, {Options options}) async {
    final response = await apiDelegate.tenantsIdGet(
      id,
      options: options,
    );

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.tenantsIdGet_decode(response);
    }
  }

  /// Get tenant details
  ///
  /// Get tenant details
  /// Update an existing tenant
  ///
  /// Update an existing tenant
  Future<Tenant> tenantsIdPatch(String id,
      {Options options, Tenant tenant}) async {
    final response =
        await apiDelegate.tenantsIdPatch(id, options: options, tenant: tenant);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.tenantsIdPatch_decode(response);
    }
  }

  /// Update an existing tenant
  ///
  /// Update an existing tenant
  /// Create a new tenant
  ///
  /// Create a new tenant
  Future<Tenant> tenantsPost({Options options, Tenant tenant}) async {
    final response =
        await apiDelegate.tenantsPost(options: options, tenant: tenant);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.tenantsPost_decode(response);
    }
  }

  /// Create a new tenant
  ///
  /// Create a new tenant
  /// List all Terminals
  ///
  /// List all Terminals
  Future<List<Terminal>> terminalsGet({Options options}) async {
    final response = await apiDelegate.terminalsGet(
      options: options,
    );

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.terminalsGet_decode(response);
    }
  }

  /// List all Terminals
  ///
  /// List all Terminals
  /// Get terminal details
  ///
  /// Get terminal details
  Future<Terminal> terminalsIdGet(String id, {Options options}) async {
    final response = await apiDelegate.terminalsIdGet(
      id,
      options: options,
    );

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.terminalsIdGet_decode(response);
    }
  }

  /// Get terminal details
  ///
  /// Get terminal details
  /// Update an existing terminal
  ///
  /// Update an existing terminal
  Future<Terminal> terminalsIdPatch(String id,
      {Options options, Terminal terminal}) async {
    final response = await apiDelegate.terminalsIdPatch(id,
        options: options, terminal: terminal);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.terminalsIdPatch_decode(response);
    }
  }

  /// Update an existing terminal
  ///
  /// Update an existing terminal
  /// Create a new Terminal
  ///
  /// Create a new Terminal
  Future<Terminal> terminalsPost({Options options, Terminal terminal}) async {
    final response =
        await apiDelegate.terminalsPost(options: options, terminal: terminal);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.terminalsPost_decode(response);
    }
  }

  /// Create a new Terminal
  ///
  /// Create a new Terminal
  /// List all users
  ///
  /// List all users
  Future<List<User>> usersGet(
      {Options options, String name, UserRole role}) async {
    final response =
        await apiDelegate.usersGet(options: options, name: name, role: role);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.usersGet_decode(response);
    }
  }

  /// List all users
  ///
  /// List all users
  /// Delete the user
  ///
  /// Delete the user
  Future usersIdDelete(String id, {Options options}) async {
    final response = await apiDelegate.usersIdDelete(
      id,
      options: options,
    );

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.usersIdDelete_decode(response);
    }
  }

  /// Delete the user
  ///
  /// Delete the user
  /// Get user details
  ///
  /// Get user details
  Future<User> usersIdGet(String id, {Options options}) async {
    final response = await apiDelegate.usersIdGet(
      id,
      options: options,
    );

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.usersIdGet_decode(response);
    }
  }

  /// Get user details
  ///
  /// Get user details
  /// Update an existing user
  ///
  /// Update an existing user
  Future<User> usersIdPatch(String id, {Options options, User user}) async {
    final response =
        await apiDelegate.usersIdPatch(id, options: options, user: user);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.usersIdPatch_decode(response);
    }
  }

  /// Update an existing user
  ///
  /// Update an existing user
  /// Create a new user
  ///
  /// Create a new user
  Future<User> usersPost({Options options, User user}) async {
    final response = await apiDelegate.usersPost(options: options, user: user);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.usersPost_decode(response);
    }
  }

  /// Create a new user
  ///
  /// Create a new user
  /// List all Yards
  ///
  /// List all Yards
  Future<List<Yard>> yardsGet({Options options}) async {
    final response = await apiDelegate.yardsGet(
      options: options,
    );

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.yardsGet_decode(response);
    }
  }

  /// List all Yards
  ///
  /// List all Yards
  /// Get yard details
  ///
  /// Get yard details
  Future<Yard> yardsIdGet(String id, {Options options}) async {
    final response = await apiDelegate.yardsIdGet(
      id,
      options: options,
    );

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.yardsIdGet_decode(response);
    }
  }

  /// Get yard details
  ///
  /// Get yard details
  /// Update an existing yard
  ///
  /// Update an existing yard
  Future<Yard> yardsIdPatch(String id, {Options options, Yard yard}) async {
    final response =
        await apiDelegate.yardsIdPatch(id, options: options, yard: yard);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.yardsIdPatch_decode(response);
    }
  }

  /// Update an existing yard
  ///
  /// Update an existing yard
  /// Create a new Yard
  ///
  /// Create a new Yard
  Future<Yard> yardsPost({Options options, Yard yard}) async {
    final response = await apiDelegate.yardsPost(options: options, yard: yard);

    if (response.statusCode >= 400) {
      throw ApiException(response.statusCode, await decodeBodyBytes(response));
    } else {
      return await apiDelegate.yardsPost_decode(response);
    }
  }

  /// Create a new Yard
  ///
  /// Create a new Yard
}

class DefaultApiDelegate {
  final ApiClient apiClient;

  DefaultApiDelegate(this.apiClient) : assert(apiClient != null);

  Future<ApiResponse> carriersGet({Options options}) async {
    Object postBody;

    // verify required params are set

    // create path and map variables
    final __path = '/carriers';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<List<Carrier>> carriersGet_decode(ApiResponse response) async {
    if (response.body != null) {
      return (LocalApiClient.deserializeFromString(
              await decodeBodyBytes(response), 'List<Carrier>') as List)
          .map((item) => item as Carrier)
          .toList();
    }

    return null;
  }

  Future<ApiResponse> carriersIdGet(String id, {Options options}) async {
    Object postBody;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, 'Missing required param: id');
    }

    // create path and map variables
    final __path = '/carriers/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Carrier> carriersIdGet_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'Carrier') as Carrier;
    }

    return null;
  }

  Future<ApiResponse> carriersIdPatch(String id,
      {Options options, Carrier carrier}) async {
    Object postBody = carrier;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, 'Missing required param: id');
    }

    // create path and map variables
    final __path = '/carriers/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'PATCH';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Carrier> carriersIdPatch_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'Carrier') as Carrier;
    }

    return null;
  }

  Future<ApiResponse> carriersPost({Options options, Carrier carrier}) async {
    Object postBody = carrier;

    // verify required params are set

    // create path and map variables
    final __path = '/carriers';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'POST';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Carrier> carriersPost_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'Carrier') as Carrier;
    }

    return null;
  }

  Future<ApiResponse> containersGet({Options options}) async {
    Object postBody;

    // verify required params are set

    // create path and map variables
    final __path = '/containers';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<List<Container>> containersGet_decode(ApiResponse response) async {
    if (response.body != null) {
      return (LocalApiClient.deserializeFromString(
              await decodeBodyBytes(response), 'List<Container>') as List)
          .map((item) => item as Container)
          .toList();
    }

    return null;
  }

  Future<ApiResponse> containersIdGet(String id, {Options options}) async {
    Object postBody;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, 'Missing required param: id');
    }

    // create path and map variables
    final __path =
        '/containers/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Container> containersIdGet_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'Container') as Container;
    }

    return null;
  }

  Future<ApiResponse> containersIdPatch(String id,
      {Options options, Container container}) async {
    Object postBody = container;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, 'Missing required param: id');
    }

    // create path and map variables
    final __path =
        '/containers/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'PATCH';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Container> containersIdPatch_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'Container') as Container;
    }

    return null;
  }

  Future<ApiResponse> containersPost(
      {Options options, Container container}) async {
    Object postBody = container;

    // verify required params are set

    // create path and map variables
    final __path = '/containers';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'POST';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Container> containersPost_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'Container') as Container;
    }

    return null;
  }

  Future<ApiResponse> customersGet({Options options}) async {
    Object postBody;

    // verify required params are set

    // create path and map variables
    final __path = '/customers';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<List<Customer>> customersGet_decode(ApiResponse response) async {
    if (response.body != null) {
      return (LocalApiClient.deserializeFromString(
              await decodeBodyBytes(response), 'List<Customer>') as List)
          .map((item) => item as Customer)
          .toList();
    }

    return null;
  }

  Future<ApiResponse> customersIdGet(String id, {Options options}) async {
    Object postBody;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, 'Missing required param: id');
    }

    // create path and map variables
    final __path =
        '/customers/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Customer> customersIdGet_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'Customer') as Customer;
    }

    return null;
  }

  Future<ApiResponse> customersIdPatch(String id,
      {Options options, Customer customer}) async {
    Object postBody = customer;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, 'Missing required param: id');
    }

    // create path and map variables
    final __path =
        '/customers/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'PATCH';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Customer> customersIdPatch_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'Customer') as Customer;
    }

    return null;
  }

  Future<ApiResponse> customersPost(
      {Options options, Customer customer}) async {
    Object postBody = customer;

    // verify required params are set

    // create path and map variables
    final __path = '/customers';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'POST';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Customer> customersPost_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'Customer') as Customer;
    }

    return null;
  }

  Future<ApiResponse> healthGet({Options options}) async {
    Object postBody;

    // verify required params are set

    // create path and map variables
    final __path = '/health';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>[];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future healthGet_decode(ApiResponse response) async {
    if (response.body != null) {}

    return;
  }

  Future<ApiResponse> ordersGet({Options options}) async {
    Object postBody;

    // verify required params are set

    // create path and map variables
    final __path = '/orders';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<List<Order>> ordersGet_decode(ApiResponse response) async {
    if (response.body != null) {
      return (LocalApiClient.deserializeFromString(
              await decodeBodyBytes(response), 'List<Order>') as List)
          .map((item) => item as Order)
          .toList();
    }

    return null;
  }

  Future<ApiResponse> ordersIdGet(String id, {Options options}) async {
    Object postBody;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, 'Missing required param: id');
    }

    // create path and map variables
    final __path = '/orders/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Order> ordersIdGet_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'Order') as Order;
    }

    return null;
  }

  Future<ApiResponse> ordersIdPatch(String id,
      {Options options, Order order}) async {
    Object postBody = order;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, 'Missing required param: id');
    }

    // create path and map variables
    final __path = '/orders/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'PATCH';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Order> ordersIdPatch_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'Order') as Order;
    }

    return null;
  }

  Future<ApiResponse> ordersPost({Options options, Order order}) async {
    Object postBody = order;

    // verify required params are set

    // create path and map variables
    final __path = '/orders';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'POST';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Order> ordersPost_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'Order') as Order;
    }

    return null;
  }

  Future<ApiResponse> tenantsGet({Options options}) async {
    Object postBody;

    // verify required params are set

    // create path and map variables
    final __path = '/tenants';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<List<Tenant>> tenantsGet_decode(ApiResponse response) async {
    if (response.body != null) {
      return (LocalApiClient.deserializeFromString(
              await decodeBodyBytes(response), 'List<Tenant>') as List)
          .map((item) => item as Tenant)
          .toList();
    }

    return null;
  }

  Future<ApiResponse> tenantsIdGet(String id, {Options options}) async {
    Object postBody;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, 'Missing required param: id');
    }

    // create path and map variables
    final __path = '/tenants/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Tenant> tenantsIdGet_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'Tenant') as Tenant;
    }

    return null;
  }

  Future<ApiResponse> tenantsIdPatch(String id,
      {Options options, Tenant tenant}) async {
    Object postBody = tenant;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, 'Missing required param: id');
    }

    // create path and map variables
    final __path = '/tenants/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'PATCH';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Tenant> tenantsIdPatch_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'Tenant') as Tenant;
    }

    return null;
  }

  Future<ApiResponse> tenantsPost({Options options, Tenant tenant}) async {
    Object postBody = tenant;

    // verify required params are set

    // create path and map variables
    final __path = '/tenants';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'POST';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Tenant> tenantsPost_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'Tenant') as Tenant;
    }

    return null;
  }

  Future<ApiResponse> terminalsGet({Options options}) async {
    Object postBody;

    // verify required params are set

    // create path and map variables
    final __path = '/terminals';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<List<Terminal>> terminalsGet_decode(ApiResponse response) async {
    if (response.body != null) {
      return (LocalApiClient.deserializeFromString(
              await decodeBodyBytes(response), 'List<Terminal>') as List)
          .map((item) => item as Terminal)
          .toList();
    }

    return null;
  }

  Future<ApiResponse> terminalsIdGet(String id, {Options options}) async {
    Object postBody;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, 'Missing required param: id');
    }

    // create path and map variables
    final __path =
        '/terminals/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Terminal> terminalsIdGet_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'Terminal') as Terminal;
    }

    return null;
  }

  Future<ApiResponse> terminalsIdPatch(String id,
      {Options options, Terminal terminal}) async {
    Object postBody = terminal;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, 'Missing required param: id');
    }

    // create path and map variables
    final __path =
        '/terminals/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'PATCH';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Terminal> terminalsIdPatch_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'Terminal') as Terminal;
    }

    return null;
  }

  Future<ApiResponse> terminalsPost(
      {Options options, Terminal terminal}) async {
    Object postBody = terminal;

    // verify required params are set

    // create path and map variables
    final __path = '/terminals';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'POST';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Terminal> terminalsPost_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'Terminal') as Terminal;
    }

    return null;
  }

  Future<ApiResponse> usersGet(
      {Options options, String name, UserRole role}) async {
    Object postBody;

    // verify required params are set

    // create path and map variables
    final __path = '/users';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    if (name != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'name', name));
    }
    if (role != null) {
      queryParams.addAll(convertParametersForCollectionFormat(
          LocalApiClient.parameterToString, '', 'role', role));
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<List<User>> usersGet_decode(ApiResponse response) async {
    if (response.body != null) {
      return (LocalApiClient.deserializeFromString(
              await decodeBodyBytes(response), 'List<User>') as List)
          .map((item) => item as User)
          .toList();
    }

    return null;
  }

  Future<ApiResponse> usersIdDelete(String id, {Options options}) async {
    Object postBody;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, 'Missing required param: id');
    }

    // create path and map variables
    final __path = '/users/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'DELETE';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future usersIdDelete_decode(ApiResponse response) async {
    if (response.body != null) {}

    return;
  }

  Future<ApiResponse> usersIdGet(String id, {Options options}) async {
    Object postBody;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, 'Missing required param: id');
    }

    // create path and map variables
    final __path = '/users/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<User> usersIdGet_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'User') as User;
    }

    return null;
  }

  Future<ApiResponse> usersIdPatch(String id,
      {Options options, User user}) async {
    Object postBody = user;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, 'Missing required param: id');
    }

    // create path and map variables
    final __path = '/users/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'PATCH';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<User> usersIdPatch_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'User') as User;
    }

    return null;
  }

  Future<ApiResponse> usersPost({Options options, User user}) async {
    Object postBody = user;

    // verify required params are set

    // create path and map variables
    final __path = '/users';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'POST';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<User> usersPost_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'User') as User;
    }

    return null;
  }

  Future<ApiResponse> yardsGet({Options options}) async {
    Object postBody;

    // verify required params are set

    // create path and map variables
    final __path = '/yards';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<List<Yard>> yardsGet_decode(ApiResponse response) async {
    if (response.body != null) {
      return (LocalApiClient.deserializeFromString(
              await decodeBodyBytes(response), 'List<Yard>') as List)
          .map((item) => item as Yard)
          .toList();
    }

    return null;
  }

  Future<ApiResponse> yardsIdGet(String id, {Options options}) async {
    Object postBody;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, 'Missing required param: id');
    }

    // create path and map variables
    final __path = '/yards/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = [];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'GET';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Yard> yardsIdGet_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'Yard') as Yard;
    }

    return null;
  }

  Future<ApiResponse> yardsIdPatch(String id,
      {Options options, Yard yard}) async {
    Object postBody = yard;

    // verify required params are set
    if (id == null) {
      throw ApiException(400, 'Missing required param: id');
    }

    // create path and map variables
    final __path = '/yards/{id}'.replaceAll('{' + 'id' + '}', id.toString());

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'PATCH';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Yard> yardsIdPatch_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'Yard') as Yard;
    }

    return null;
  }

  Future<ApiResponse> yardsPost({Options options, Yard yard}) async {
    Object postBody = yard;

    // verify required params are set

    // create path and map variables
    final __path = '/yards';

    // query params
    final queryParams = <QueryParam>[];
    final headerParams = <String, String>{}
      ..addAll(options?.headers?.cast<String, String>() ?? {});
    if (headerParams['Accept'] == null) {
      // we only want to accept this format as we can parse it
      headerParams['Accept'] = 'application/json';
    }

    final authNames = <String>['ApiKeyAuth'];
    final opt = options ?? Options();

    final contentTypes = ['application/json'];

    if (contentTypes.isNotEmpty && headerParams['Content-Type'] == null) {
      headerParams['Content-Type'] = contentTypes[0];
    }
    if (postBody != null) {
      postBody = LocalApiClient.serialize(postBody);
    }

    opt.headers = headerParams;
    opt.method = 'POST';

    return await apiClient.invokeAPI(
        __path, queryParams, postBody, authNames, opt);
  }

  Future<Yard> yardsPost_decode(ApiResponse response) async {
    if (response.body != null) {
      return LocalApiClient.deserializeFromString(
          await decodeBodyBytes(response), 'Yard') as Yard;
    }

    return null;
  }
}
